LNT: LLVM Nightly Test Infrastructure
=====================================

About
-----

LNT is an infrastructure for performance testing. The software itself
consists of two main parts, a web application for accessing and visualizing
performance data, and command line utilities to allow users to generate and
submit test results to the server.

The package was originally written for use in testing LLVM compiler
technologies, but is designed to be usable for the performance testing of any
software.


Documentation
-------------

The official LNT documentation is available online at: https://llvm.org/docs/lnt


Source
------

The LNT source is available in the llvm-lnt repository: https://github.com/llvm/llvm-lnt


Contributing
------------

To get started, please look at the [Developer Guide](https://llvm.org/docs/lnt/developer_guide.html) in the official documentation.
